tax2tree ChangeLog
==================

tax2tree 1.1-dev
----------------

Changes:

* BSD-licensed
* migrated to github
* removed cogent as a dependency
* top level is now d__

tax2tree 1.0
------------

* initial release
